==> rheolef_6.7.orig.tar.gz: rheolef-6.7/doc/pexamples/burgers_dg.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
SRCDIR=${SRCDIR-"$TOP_SRCDIR/doc/pexample"}
NPROC_MAX=${NPROC_MAX-"3"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

#echo "      not yet (skipped)"
#exit 0

err_linf_l1_P0="0.1"
err_linf_l1_P1d="0.06"

status=0

run "mkgeo_grid -e 50 -a -1 -b 1 > tmp.geo"
if test $? -ne 0; then status=1; fi

loop_mpirun "./burgers_dg tmp P0d 500 2.5 2>/dev/null | ./harten_error $err_linf_l1_P0 >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

loop_mpirun "./burgers_dg tmp P1d 500 2.5 2>/dev/null | ./harten_error $err_linf_l1_P1d >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

run "rm -f tmp.geo"

exit $status

==> rheolef_7.0.orig.tar.gz: rheolef-7.0/doc/pexamples/burgers_dg.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2018 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# -------------------------------------------------------------------------
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
SRCDIR=${SRCDIR-"$TOP_SRCDIR/doc/pexamples"}
NPROC_MAX=${NPROC_MAX-"3"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

#echo "      not yet (skipped)"
#exit 0

err_linf_l1_P0="0.1"
err_linf_l1_P1d="0.06"

status=0

run "mkgeo_grid -e 50 -a -1 -b 1 > tmp.geo"
if test $? -ne 0; then status=1; fi

loop_mpirun "./burgers_dg tmp P0d 500 2.5 2>/dev/null | ./harten_error $err_linf_l1_P0 >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

loop_mpirun "./burgers_dg tmp P1d 500 2.5 2>/dev/null | ./harten_error $err_linf_l1_P1d >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

run "rm -f tmp.geo"

exit $status
